- comments on all objects

- SAP HANA ???

- dlt library ???
  - https://dlthub.com/docs/pipelines/sql_database_oracle/load-data-with-python-from-sql_database_oracle-to-duckdb
  - https://dlthub.com/docs/intro

	